@@ -27,6 +27,13 @@ func (h *Handler) processImageStreamWatchEvent(is *imagev1.ImageStream, deleted
 	} else {
 		logrus.Debugf("Imagestream %s watch event do upsert %v; no errors in prep %v,  possibly update operator conditions %v", is.Name, doUpsert, err == nil, cfg != nil)
 	}
+	if cfg != nil {
+		if util.IsNonX86Arch(cfg) {
+			logrus.Printf("ignoring watch event for imagestream %s ignored because we are on %s",
+				is.Name, cfg.Spec.Architectures[0])
+			return nil
+		}
+	}
 	if !doUpsert {
 		if err != nil {
 			return err
