@@ -15,8 +15,8 @@ import (
 	imagev1lister "github.com/openshift/client-go/image/listers/image/v1"
 	templatev1lister "github.com/openshift/client-go/template/listers/template/v1"
 	v1 "github.com/openshift/api/samples/v1"
-	sampleclientv1 "github.com/openshift/cluster-samples-operator/pkg/generated/clientset/versioned/typed/samples/v1"
-	configv1lister "github.com/openshift/cluster-samples-operator/pkg/generated/listers/samples/v1"
+	sampleclientv1 "github.com/openshift/client-go/samples/clientset/versioned/typed/samples/v1"
+	configv1lister "github.com/openshift/client-go/samples/listers/samples/v1"
 	"github.com/sirupsen/logrus"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
